@@ -17,7 +17,8 @@ _HELP_MESSAGE_BINARY = """
         -o <output_path>\t\t    Output path
         \t\t\t\t    (If you want to generate the specific file name, add the output path with file name.)
         -f <format>\t\t\t    Output file format (excel, csv, opossum, yaml)
-        -d <db_url>\t\t\t    DB Connection(format :'postgresql://username:password@host:port/database_name')"""
+        -d <db_url>\t\t\t    DB Connection(format :'postgresql://username:password@host:port/database_name')
+        --notice\t\t\t    Print the open source license notice text."""
 
 
 def print_help_msg():
